SimStepData: Simulating k-box model abrupt 4xCO2 step responses

View source: R/simulate_data.R

SimStepDataR Documentation

Simulating k-box model abrupt 4xCO2 step responses

Description

SimStepData takes physical parameters of a k-box model and simulates the first n years of its response to an abrupt 4xCO2 forcing.

Usage

SimStepData(gamma, C, kappa, epsilon, sigma_eta, sigma_xi, F_4xCO2, n)

Arguments

gamma

stochastic forcing correlation parameter.

C

vector of box heat capacities.

kappa

vector of heat transfer coefficients.

epsilon

deep ocean heat uptake efficacy factor.

sigma_eta

stochastic forcing standard deviation parameter.

sigma_xi

standard deviation of stochastic temperature disturbances.

F_4xCO2

effective radiative forcing due to CO2 quadrupling.

n

length of simulation in years.

Value

SimStepData returns a matrix with two rows containing time series of global mean surface temperature and top-of-the-atmosphere net downward radiative flux respectively.

See Also

BuildMatrices, FitKalman.

Examples

# set physical parameters
parameters <- list(
  gamma = 2.2,
  C = c(7.0, 80.0),
  kappa = c(1.2, 0.75),
  epsilon = 1.2,
  sigma_eta = 0.54,
  sigma_xi = 0.72,
  F_4xCO2 = 7.4,
  n = 150
)

# simulate step response
step <- with(parameters, {
  SimStepData(gamma, C, kappa, epsilon, sigma_eta, sigma_xi, F_4xCO2, n)
})

# plot results
plot.ts(t(step), main = "Simulated Step Response")

donaldcummins/EBM documentation built on Oct. 15, 2024, 6:17 a.m.